Summary: Library providing specific CCP4 functionality 
Name: libccp4
Version: 6.3.1
Release: 4%{?dist}
License: LGPLv3
Group: System Environment/Libraries
URL: ftp://ftp.ccp4.ac.uk/opensource/
Source0: ftp://ftp.ccp4.ac.uk/opensource/%{name}-%{version}.tar.gz
Patch0: libccp4-ccp4_sysdep.patch
BuildRequires: gcc-gfortran
BuildRequires: m4
BuildRequires: mmdb-devel
# prevent breakage on f19
%if 0%{?fedora} >= 20
Obsoletes: gpp4 < %{version}-%{release}
%endif

%description

The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

The library contains several sub components: 
  * CMTZ library -- Contains a variety of functions for manipulating 
    the data structure, for example adding crystals, datasets or columns. 
    The data structure can be dumped to an output MTZ data file.
  * CMAP library -- Functions defining the C-level API for accessing 
    CCP4 map files.
  * CSYM library -- a collection of functions centered around a data file 
    syminfo.lib which is auto-generated from sgtbx (the Space Group Toolbox 
    of cctbx).
  * CCP4 utility library -- many utility functions which either give 
    specific CCP4 or platform independent functionality.
  * CCP4 Parser library -- provides CCP4-style parsing, as used for 
    processing keywords of CCP4 programs, MTZ header records, etc.
  * CCP4 resizable arrays -- defines an object and methods which looks 
    just like a simple C array, but can be resized at will without 
    incurring excessive overheads.

This package contains the shared library components needed for programs
that have been compiled with the libccp4 library. 

%package devel
Summary: Header files and library for developing free CCP4 programs
Requires: %{name}%{?_isa} = %{version}-%{release}
Group: Development/Libraries
# prevent breakage on f19
%if 0%{?fedora} >= 20
Obsoletes: gpp4-devel < %{version}-%{release}
%endif

%description devel
The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

This package contains libraries and header files needed for program
development.

%prep
%setup -q
%patch0 -p0

%build
%configure --enable-shared --disable-static
# die rpath, die.
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL='install -p'

# remove unpackaged files from the buildroot
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc COPYING.LESSER
%{_datadir}/ccp4
%{_libdir}/libccp4c.so.0
%{_libdir}/libccp4c.so.0.0.0
%{_libdir}/libccp4f.so.0
%{_libdir}/libccp4f.so.0.0.0

%files devel
%{_includedir}/ccp4
%{_libdir}/libccp4c.so
%{_libdir}/libccp4f.so
%{_libdir}/pkgconfig/%{name}c.pc
%{_libdir}/pkgconfig/%{name}f.pc

%changelog
* Wed Aug 7 2013 Tim Fenn <tim.fenn@gmail.com> - 6.3.1-4
- patch ccp4_sysdep to fix arm build

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jul 8 2013 Tim Fenn <tim.fenn@gmail.com> - 6.3.1-3
- add conditional to prevent broken deps on f19 and below

* Sun Jun 2 2013 Tim Fenn <tim.fenn@gmail.com> - 6.3.1-2
- specfile cleanup

* Thu May 30 2013 Tim Fenn <tim.fenn@gmail.com> - 6.3.1-1
- Initial build
